QueryResult

Enum QueryResult 

pub enum QueryResult {
    Select(ResultSet),
    Affected(u64),
    Empty,
}
The result of a query execution.

Variants



Select(ResultSet)

A result set with rows.



Affected(u64)

The number of rows affected by an INSERT/UPDATE/DELETE.



Empty

An empty result (e.g., from DDL statements).

Implementations

Source

impl QueryResult

pub fn select(result_set: ResultSet) -> Self

Creates a new select result.

pub const fn affected(count: u64) -> Self

Creates an affected rows result.

pub const fn empty() -> Self

Creates an empty result.

pub const fn is_select(&self) -> bool

Returns true if this is a select result.

pub fn as_select(&self) -> Option<&ResultSet>

Returns the result set if this is a select result.

pub fn into_select(self) -> Option<ResultSet>

Consumes and returns the result set if this is a select result.

pub const fn affected_rows(&self) -> Option<u64>

Returns the affected row count if this is an affected result.